Module builder

Module builder 

Transaction/message builder helpers. High-level transaction builder APIs.

Structs

TxBuilder
High-level builder for Solana versioned transaction messages.
UnsignedTx
Unsigned transaction wrapper.

Enums

BuilderError
Builder-layer errors.
TxMessageVersion
Transaction message version emitted by TxBuilder.

Constants

DEFAULT_DEVELOPER_TIP_LAMPORTS
Default lamports tipped by TxBuilder::tip_developer.
DEFAULT_DEVELOPER_TIP_RECIPIENT
Default developer tip recipient used by TxBuilder::tip_developer.
MAX_TRANSACTION_ACCOUNT_LOCKS
Current maximum number of account locks allowed per transaction.
MAX_TRANSACTION_WIRE_BYTES
Current maximum serialized transaction payload size accepted by Solana networking.