pub struct RoutingPolicy {
pub next_leaders: usize,
pub backup_validators: usize,
pub max_parallel_sends: usize,
}Expand description
Routing controls used for direct and hybrid submit paths.
Fields
next_leaders: usizeNumber of upcoming leaders to include after current leader.
backup_validators: usizeNumber of static backup validators to include.
max_parallel_sends: usizeMaximum concurrent direct sends.
Implementations
Sourceimpl RoutingPolicy
impl RoutingPolicy
Sourcepub fn normalized(self) -> Self
pub fn normalized(self) -> Self
Returns a normalized policy with bounded minimums.