TxFlowSafetyQuality

Enum TxFlowSafetyQuality 

pub enum TxFlowSafetyQuality {
    Stable,
    Provisional,
    ReorgRisk,
    Stale,
    Degraded,
    IncompleteControlPlane,
}
Coarse toxic-flow quality used by submit guards.

Variants



Stable

Required inputs are present, coherent, and safe to use.



Provisional

Inputs exist but have not reached a stable confirmation boundary yet.



ReorgRisk

Inputs exist but the current branch still carries material reorg risk.



Stale

Inputs are present but stale.



Degraded

Inputs are present but mutually inconsistent.



IncompleteControlPlane

Required inputs are still missing.